@@ -11,8 +11,10 @@ use strict;
 use AutoLoader 'AUTOLOAD';
 use Apache::Session;
 use base qw(Apache::Session);
+use Lemonldap::NG::Common::Apache::Session::Store;
+use Lemonldap::NG::Common::Apache::Session::Lock;
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.4.0';
 
 sub _load {
     my $backend = shift;
@@ -31,10 +33,31 @@ sub populate {
         no strict 'refs';
         $self = $self->$backend(@_);
     }
+    if ( $self->{args}->{generateModule} ) {
+        my $generate = $self->{args}->{generateModule};
+        eval "require $generate";
+        die $@ if ($@);
+        $self->{generate} = \&{ $generate . "::generate" };
+        $self->{validate} = \&{ $generate . "::validate" };
+    }
     if ( $self->{args}->{setId} ) {
         $self->{generate} = \&setId;
         $self->{validate} = sub { 1 };
     }
+
+    # If cache is configured, use our specific object store module
+    if ( $self->{args}->{localStorage} ) {
+        $self->{args}->{object_store} = $self->{object_store};
+        $self->{object_store} =
+          Lemonldap::NG::Common::Apache::Session::Store->new($self);
+    }
+
+    # If cache is configured, use our specific lock_manager object module
+    if ( $self->{args}->{localStorage} ) {
+        $self->{args}->{lock_manager} = $self->{lock_manager};
+        $self->{lock_manager} =
+          Lemonldap::NG::Common::Apache::Session::Lock->new($self);
+    }
     return $self;
 }
 
@@ -71,6 +94,35 @@ sub searchOn {
     return \%res;
 }
 
+sub searchOnExpr {
+    my ( $class, $args, $selectField, $value, @fields ) = splice @_;
+    my $backend = $args->{backend};
+    _load($backend);
+    if ( $backend->can('searchOnExpr') ) {
+        return $backend->searchOnExpr( $args, $selectField, $value, @fields );
+    }
+    $value = quotemeta($value);
+    $value =~ s/\\\*/\.\*/g;
+    $value = qr/^$value$/;
+    my %res = ();
+    $class->get_key_from_all_sessions(
+        $args,
+        sub {
+            my $entry = shift;
+            my $id    = shift;
+            return undef unless ( $entry->{$selectField} =~ $value );
+            if (@fields) {
+                $res{$id}->{$_} = $entry->{$_} foreach (@fields);
+            }
+            else {
+                $res{$id} = $entry;
+            }
+            undef;
+        }
+    );
+    return \%res;
+}
+
 sub searchLt {
     my ( $class, $args, $selectField, $value, @fields ) = splice @_;
     my %res = ();
@@ -102,7 +154,8 @@ sub get_key_from_all_sessions {
         return $backend->get_key_from_all_sessions(@_);
     }
     if ( $backend =~
-        /^Apache::Session::(MySQL|Postgres|Oracle|Sybase|Informix)$/ )
+/^Apache::Session::(MySQL|MySQL::NoLock|Postgres|Oracle|Sybase|Informix)$/
+      )
     {
         return $class->_dbiGKFAS( $1, @_ );
     }
@@ -123,7 +176,7 @@ sub decodeThaw64 {
     require Storable;
     require MIME::Base64;
     my $s = shift;
-    return Storable::thaw( MIME::Base64::decode_64($s) );
+    return Storable::thaw( MIME::Base64::decode_base64($s) );
 }
 
 sub _dbiGKFAS {
@@ -176,15 +229,24 @@ sub _FileGKFAS {
         open F, "$args->{Directory}/$f";
         my $row = join '', <F>;
         if ( ref($data) eq 'CODE' ) {
-            $res{$f} = &$data( Storable::thaw($row), $f );
+            eval { $res{$f} = &$data( Storable::thaw($row), $f ); };
+            if ($@) {
+                $res{$f} = &$data( undef, $f );
+            }
         }
         elsif ($data) {
             $data = [$data] unless ( ref($data) );
-            my $tmp = Storable::thaw($row);
-            $res{$f}->{$_} = $tmp->{$_} foreach (@$data);
+            my $tmp;
+            eval { $tmp = Storable::thaw($row); };
+            if ($@) {
+                $res{$f}->{$_} = undef foreach (@$data);
+            }
+            else {
+                $res{$f}->{$_} = $tmp->{$_} foreach (@$data);
+            }
         }
         else {
-            $res{$f} = Storable::thaw($row);
+            eval { $res{$f} = Storable::thaw($row); };
         }
     }
     return \%res;
@@ -265,7 +327,7 @@ sub _LDAPGKFAS {
         my ( $k, $v ) =
           ( $entry->get_value('cn'), $entry->get_value('description') );
         eval { $v = decodeThaw64($v); };
-        next if($@);
+        next if ($@);
         if ( ref($data) eq 'CODE' ) {
             $res{$k} = &$data( $v, $k );
         }
