@@ -17,7 +17,7 @@ use Net::CIDR::Lite;
 
 #parameter syslog Indicates syslog facility for logging user actions
 
-our $VERSION = '1.3.3';
+our $VERSION = '1.4.6';
 our $_SUPER;
 our @ISA;
 
@@ -272,6 +272,7 @@ a {
     print
       '<center><a href="http://lemonldap-ng.org">LemonLDAP::NG</a></center>';
     print STDERR ( ref($self) || $self ) . " error: $t1, $t2\n";
+    print $cgi->end_html();
     $self->quit();
 }
 
@@ -367,7 +368,7 @@ sub extract_lang {
         $lang = ( split /-/, $lang )[0];
 
         # Go to next if lang was already added
-        next if grep( /$lang/, @res );
+        next if grep( /\Q$lang\E/, @res );
 
         # Store lang only if size is 2 characters
         push @res, $lang if ( length($lang) == 2 );
