@@ -9,7 +9,8 @@ package Lemonldap::NG::Common::Conf;
 
 use strict;
 no strict 'refs';
-use Lemonldap::NG::Common::Conf::Constants;    #inherits
+use Lemonldap::NG::Common::Conf::Constants;     #inherits
+use Lemonldap::NG::Common::Conf::Attributes;    #inherits
 use Lemonldap::NG::Common::Crypto
   ;    #link protected cipher Object "cypher" in configuration hash
 use Config::IniFiles;
@@ -19,7 +20,7 @@ use Config::IniFiles;
 #inherits Lemonldap::NG::Common::Conf::SOAP
 #inherits Lemonldap::NG::Common::Conf::LDAP
 
-our $VERSION = '1.3.0';
+our $VERSION = '1.4.1';
 our $msg;
 our $iniObj;
 
@@ -121,6 +122,7 @@ sub saveConf {
 
     unless ( $tmp > 0 ) {
         $msg .= "Configuration $conf->{cfgNum} not stored.\n";
+        $self->unlock();
         return ( $tmp ? $tmp : UNKNOWN_ERROR );
     }
 
@@ -138,6 +140,8 @@ sub saveConf {
 # @return Lemonldap::NG configuration
 sub getConf {
     my ( $self, $args ) = @_;
+
+    # Use only cache to get conf
     if (    $args->{local}
         and ref( $self->{refLocalStorage} )
         and my $res = $self->{refLocalStorage}->get('conf') )
@@ -145,11 +149,13 @@ sub getConf {
         $msg .= "Get configuration from cache without verification.\n";
         return $res;
     }
+
+    # Check cfgNum in conf backend
+    # Get conf in backend only if a newer configuration is available
     else {
         $args->{cfgNum} ||= $self->lastCfg;
         unless ( $args->{cfgNum} ) {
-            $msg .= "No configuration available.\n";
-            return 0;
+            $msg .= "No configuration available in backend.\n";
         }
         my $r;
         unless ( ref( $self->{refLocalStorage} ) ) {
@@ -162,29 +168,58 @@ sub getConf {
             if ( ref($r) and $r->{cfgNum} == $args->{cfgNum} ) {
                 $msg .=
                   "Configuration unchanged, get configuration from cache.\n";
+                $args->{noCache} = 1;
             }
             else {
                 $r = $self->getDBConf($args);
             }
         }
-        print STDERR "Warning: key is not defined, set it in the manager !\n"
-          unless ( $r->{key} );
-        eval {
-            $r->{cipher} =
-              Lemonldap::NG::Common::Crypto->new( $r->{key}
-                  || 'lemonldap-ng-key' );
-        };
+
+        # Get default values
+        my $confAttributes = Lemonldap::NG::Common::Conf::Attributes->new();
+
+        my @attributes = $confAttributes->meta()->get_attribute_list();
+
+        foreach my $name (@attributes) {
+            unless ( defined $r->{$name} ) {
+                $r->{$name} = $confAttributes->$name;
+            }
+        }
+
+        # Create cipher object
+        eval { $r->{cipher} = Lemonldap::NG::Common::Crypto->new( $r->{key} ); };
         if ($@) {
             $msg .= "Bad key: $@. \n";
             return $r;
         }
 
+        # Adapt some values
+
         # Convert old option useXForwardedForIP into trustedProxies
         if ( defined $r->{useXForwardedForIP}
             and $r->{useXForwardedForIP} == 1 )
         {
             $r->{trustedProxies} = '*';
         }
+
+        # Force Choice backend
+        if ( $r->{authentication} eq "Choice" ) {
+            $r->{userDB}     = "Choice";
+            $r->{passwordDB} = "Choice";
+        }
+
+        # Some parameters expect key name (example), not variable ($example)
+        foreach (qw/whatToTrace/) {
+            if ( defined $r->{$_} ) {
+                $r->{$_} =~ s/^\$//;
+            }
+        }
+
+        # Store modified configuration in cache
+        $self->setLocalConf($r)
+          if ( $self->{refLocalStorage} and not( $args->{noCache} ) );
+
+        # Return configuration hash
         return $r;
     }
 }
@@ -201,7 +236,10 @@ sub getLocalConf {
     my $r = {};
 
     $section ||= DEFAULTSECTION;
-    $file ||= $self->{confFile} || DEFAULTCONFFILE;
+    $file ||=
+         $self->{confFile}
+      || $ENV{LLNG_DEFAULTCONFFILE}
+      || DEFAULTCONFFILE;
     $loaddefault = 1 unless ( defined $loaddefault );
     my $cfg;
 
@@ -327,7 +365,8 @@ sub available {
 # Call lastCfg() from the $self->{type} package.
 # @return Number of the last configuration available
 sub lastCfg {
-    return &{ $_[0]->{type} . '::lastCfg' }(@_);
+    my $result = &{ $_[0]->{type} . '::lastCfg' }(@_) || "0";
+    return $result;
 }
 
 ## @method boolean lock()
