@@ -4,7 +4,7 @@ use strict;
 use Lemonldap::NG::Common::Conf::Constants;    #inherits
 use Lemonldap::NG::Common::Conf::Serializer;
 
-our $VERSION = '1.2.2';
+our $VERSION = '1.4.0';
 
 sub prereq {
     my $self = shift;
@@ -80,7 +80,6 @@ sub store {
     }
     close FILE;
     umask($mask);
-    $self->unlock;
     return $fields->{cfgNum};
 }
 
@@ -88,7 +87,10 @@ sub load {
     my ( $self, $cfgNum, $fields ) = @_;
     my $f;
     local $/ = "";
-    open FILE, $self->{dirName} . "/lmConf-$cfgNum";
+    unless ( open FILE, $self->{dirName} . "/lmConf-$cfgNum" ) {
+        $Lemonldap::NG::Common::Conf::msg .= "Open file failed: $! \n";
+        return undef;
+    }
     while (<FILE>) {
         my ( $k, $v ) = split /\n\s+/;
         chomp $k;
