@@ -8,6 +8,7 @@ package Lemonldap::NG::Handler::CGI;
 use strict;
 
 use Lemonldap::NG::Common::CGI;
+use Lemonldap::NG::Common::Session;
 use CGI::Cookie;
 use MIME::Base64;
 
@@ -17,7 +18,7 @@ use Lemonldap::NG::Handler::SharedConf qw(:all);
 
 #link Lemonldap::NG::Handler::_CGI protected _handler
 
-our $VERSION = '1.0.2';
+our $VERSION = '1.4.1';
 
 ## @cmethod Lemonldap::NG::Handler::CGI new(hashRef args)
 # Constructor.
@@ -27,9 +28,10 @@ sub new {
     my $class = shift;
     my $self = $class->SUPER::new() or $class->abort("Unable to build CGI");
     $Lemonldap::NG::Handler::_CGI::_cgi = $self;
-    unless ($Lemonldap::NG::Handler::_CGI::cookieName) {
+    unless ( $Lemonldap::NG::Handler::_CGI::tsv->{cookieName} ) {
         Lemonldap::NG::Handler::_CGI->init(@_);
-        Lemonldap::NG::Handler::_CGI->initLocalStorage(@_);
+
+#Lemonldap::NG::Handler::_CGI->initLocalStorage(@_); # already called by _CGI->init()
     }
     unless ( eval { Lemonldap::NG::Handler::_CGI->testConf() } == OK ) {
         if ( $_[0]->{noAbort} ) {
@@ -50,7 +52,7 @@ sub new {
     }
 
     # Protection
-    if ( $self->{protection} ) {
+    if ( $self->{protection} and $self->{protection} ne 'none' ) {
         $self->authenticate();
 
         # ACCOUNTING
@@ -65,8 +67,9 @@ sub new {
             $rule =~ s/\$(\w+)/\$datas->{$1}/g;
             $rule = 0 if ( $rule eq 'deny' );
             my $r;
+
             unless ( $rule eq 'accept'
-                or Lemonldap::NG::Handler::_CGI->safe->reval($rule) )
+                or Lemonldap::NG::Handler::_CGI->safe_reval($rule) )
             {
                 $self->abort( 'Forbidden',
                     "You don't have rights to access this page" );
@@ -75,7 +78,9 @@ sub new {
         elsif ( $self->{protection} !~ /^authenticate$/i ) {
             $self->abort(
                 'Bad configuration',
-                "The rule <code>" . $self->{protection} . "</code> is not known"
+                "The rule <code>"
+                  . $self->{protection}
+                  . "</code> is not known"
             );
         }
     }
@@ -95,26 +100,39 @@ sub authenticate {
       if ( $self->{_noConf} );
     my %cookies = fetch CGI::Cookie;
     my $id;
-    unless ( $cookies{$cookieName} and $id = $cookies{$cookieName}->value ) {
+    unless ($cookies{ $tsv->{cookieName} }
+        and $id = $cookies{ $tsv->{cookieName} }->value )
+    {
         return $self->goToPortal();
     }
     unless ( $datas and $id eq $datas->{_session_id} ) {
-        unless ( $refLocalStorage and $datas = $refLocalStorage->get($id) ) {
-            my %h;
-            eval { tie %h, $globalStorage, $id, $globalStorageOptions; };
-            if ($@) {
-                return $self->goToPortal();
-            }
-            $datas->{$_} = $h{$_} foreach ( keys %h );
-            if ($refLocalStorage) {
-                $refLocalStorage->set( $id, $datas, "10 minutes" );
+
+        my $apacheSession = Lemonldap::NG::Common::Session->new(
+            {
+                storageModule        => $tsv->{globalStorage},
+                storageModuleOptions => $tsv->{globalStorageOptions},
+                cacheModule          => $tsv->{localSessionStorage},
+                cacheModuleOptions   => $tsv->{localSessionStorageOptions},
+                id                   => $id,
+                kind                 => "SSO",
             }
+        );
+
+        if ( $apacheSession->error ) {
+            Lemonldap::NG::Handler::Main::Logger->lmLog(
+                "Session $id can't be retrieved", 'info' );
+            Lemonldap::NG::Handler::Main::Logger->lmLog( $apacheSession->error,
+                'info' );
+            return $self->goToPortal();
         }
+
+        $datas->{$_} = $apacheSession->data->{$_}
+          foreach ( keys %{ $apacheSession->data } );
     }
 
     # Accounting : set user in apache logs
-    $self->setApacheUser( $datas->{$whatToTrace} );
-    $ENV{REMOTE_USER} = $datas->{$whatToTrace};
+    $self->setApacheUser( $datas->{ $tsv->{whatToTrace} } );
+    $ENV{REMOTE_USER} = $datas->{ $tsv->{whatToTrace} };
 
     return 1;
 }
@@ -176,11 +194,14 @@ sub goToPortal {
 sub _uri {
     my $vhost = $ENV{SERVER_NAME};
     my $portString =
-         $port->{$vhost}
-      || $port->{_}
+         $tsv->{port}->{$vhost}
+      || $tsv->{port}->{_}
       || $ENV{SERVER_PORT};
-    my $_https =
-      ( defined( $https->{$vhost} ) ? $https->{$vhost} : $https->{_} );
+    my $_https = (
+        defined( $tsv->{https}->{$vhost} )
+        ? $tsv->{https}->{$vhost}
+        : $tsv->{https}->{_}
+    );
     $portString =
         ( $_https  && $portString == 443 ) ? ''
       : ( !$_https && $portString == 80 )  ? ''
@@ -198,12 +219,29 @@ sub _uri {
 package Lemonldap::NG::Handler::_CGI;
 
 use strict;
-use Lemonldap::NG::Handler::SharedConf qw(:locationRules :localStorage :traces);
+
+#use Lemonldap::NG::Handler::SharedConf qw(:locationRules :localStorage :traces);
+use Lemonldap::NG::Handler::SharedConf qw(:tsv :ntsv :jailSharedVars);
+use Lemonldap::NG::Handler::Main::Jail;
 
 use base qw(Lemonldap::NG::Handler::SharedConf);
 
 our $_cgi;
 
+sub safe_reval {
+    my $class = shift;
+    my $rule  = shift;
+
+    my $jail = Lemonldap::NG::Handler::Main::Jail->new(
+        'safe'            => $ntsv->{safe},
+        'useSafeJail'     => $tsv->{useSafeJail},
+        'customFunctions' => $tsv->{customFunctions}
+    );
+    $ntsv->{safe} = $jail->build_safe();
+
+    return $ntsv->{safe}->reval($rule);
+}
+
 ## @method boolean childInit()
 # Since this is not a real Apache handler, childs have not to be initialized.
 # @return true
@@ -229,7 +267,7 @@ sub lmLog {
 # @return boolean : true if $vhost is available
 sub vhostAvailable {
     my ( $self, $vhost ) = splice @_;
-    return defined( $defaultCondition->{$vhost} );
+    return defined( $tsv->{defaultCondition}->{$vhost} );
 }
 
 ## @method boolean grant(string uri, string vhost)
@@ -246,19 +284,19 @@ sub grant {
             args     => '',
         }
     );
-    for ( my $i = 0 ; $i < $locationCount->{$vhost} ; $i++ ) {
-        if ( $uri =~ $locationRegexp->{$vhost}->[$i] ) {
-            return &{ $locationCondition->{$vhost}->[$i] }($datas);
+    for ( my $i = 0 ; $i < $tsv->{locationCount}->{$vhost} ; $i++ ) {
+        if ( $uri =~ $tsv->{locationRegexp}->{$vhost}->[$i] ) {
+            return &{ $tsv->{locationCondition}->{$vhost}->[$i] }($datas);
         }
     }
-    unless ( $defaultCondition->{$vhost} ) {
+    unless ( $tsv->{defaultCondition}->{$vhost} ) {
         $self->lmLog(
             "User rejected because VirtualHost \"$vhost\" has no configuration",
             'warn'
         );
         return 0;
     }
-    return &{ $defaultCondition->{$vhost} }($datas);
+    return &{ $tsv->{defaultCondition}->{$vhost} }($datas);
 }
 
 package Lemonldap::NG::Apache::Request;
@@ -354,7 +392,15 @@ L<Lemonldap::NG::Portal>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=back
 
 =head1 BUG REPORT
 
@@ -368,10 +414,27 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007, 2010 by Xavier Guimard
+=over
+
+=item Copyright (C) 2007, 2008, 2009, 2010, 2012 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
