@@ -22,7 +22,7 @@ use utf8;
 our $whatToTrace;
 *whatToTrace = \$Lemonldap::NG::Handler::_CGI::whatToTrace;
 
-our $VERSION = '1.3.0';
+our $VERSION = '1.4.1';
 
 our @ISA = qw(
   Lemonldap::NG::Handler::CGI
@@ -44,16 +44,19 @@ sub new {
       or Lemonldap::NG::Handler::CGI->abort( 'Unable to get configuration',
         $Lemonldap::NG::Common::Conf::msg );
 
+    # Load global configuration
+    if ( my $globalconf = $conf->getConf() ) {
+        $args->{$_} ||= $globalconf->{$_}
+          foreach (
+            qw/portal notification notificationStorage notificationStorageOptions/
+          );
+    }
+
     # Configuration from MANAGER section
     if ( my $localconf = $conf->getLocalConf(MANAGERSECTION) ) {
         $args->{$_} ||= $localconf->{$_} foreach ( keys %$localconf );
     }
 
-    # Load global configuration
-    if ( my $globalconf = $conf->getConf() ) {
-        $args->{$_} ||= $globalconf->{$_} foreach ( keys %$globalconf );
-    }
-
     my $self = $class->SUPER::new($args)
       or $class->abort( 'Unable to start ' . __PACKAGE__,
         'See Apache logs for more' );
@@ -262,9 +265,9 @@ sub listDone {
 # @param id Session identifier
 # @return HTML data
 sub delete {
-    my ( $self, $id ) = splice @_;
-    my ( $uid, $ref ) = ( $id =~ /([^_]+?)_(.+)/ );
-    my ( $n, $res );
+    my ( $self, $id )  = splice @_;
+    my ( $uid,  $ref ) = ( $id =~ /([^_]+?)_(.+)/ );
+    my ( $n,    $res );
 
     # Try to read notification
     $n = $self->{notifObject}->_get( $uid, $ref );
@@ -342,9 +345,9 @@ sub purge {
 # Build notification dump.
 # @return string XML tree
 sub notification {
-    my ( $self, $id ) = splice @_;
-    my ( $uid, $ref ) = ( $id =~ /([^_]+?)_(.+)/ );
-    my ( $n, $res );
+    my ( $self, $id )  = splice @_;
+    my ( $uid,  $ref ) = ( $id =~ /([^_]+?)_(.+)/ );
+    my ( $n,    $res );
 
     # Try to read notification
     $n = $self->{notifObject}->_get( $uid, $ref );
