@@ -9,7 +9,7 @@ package Lemonldap::NG::Manager::_i18n;
 
 use strict;
 use AutoLoader qw(AUTOLOAD);
-our $VERSION = '1.3.0';
+our $VERSION = '1.4.6';
 
 ## @method string translate(string text,string lang)
 # Returns $text translated in $lang.
@@ -50,7 +50,9 @@ sub en {
     return {
         _auth                    => 'Authentication',
         _authChoice              => 'Authentication choice',
+        _authMulti               => 'Authentication (multi)',
         _userDB                  => 'User',
+        _userDBMulti             => 'User (multi)',
         _passwordDB              => 'Password',
         _issuerDB                => 'Issuer',
         _timezone                => 'Time zone',
@@ -65,6 +67,9 @@ sub en {
         _samlToken               => 'SAML token',
         _lassoSessionDump        => 'Lasso session dump',
         _lassoIdentityDump       => 'Lasso identity dump',
+        adParams                 => 'Active Directory parameters',
+        ADPwdExpireWarning       => 'Password expire warning',
+        ADPwdMaxAge              => 'Password max age',
         advancedParams           => 'Advanced parameters',
         apacheParams             => 'Apache parameters',
         apacheAuthnLevel         => 'Authentication level',
@@ -95,6 +100,7 @@ sub en {
         dbiConnection            => 'Connection',
         dbiConnectionAuth        => 'Authentication process',
         dbiConnectionUser        => 'User process',
+        dbiExportedVars          => 'Exported variables',
         dbiParams                => 'DBI parameters',
         dbiPassword              => 'Password',
         dbiPasswordMailCol       => 'Mail field name',
@@ -105,12 +111,15 @@ sub en {
         dbiUserUser              => 'User',
         deleteNotification       => 'Mark notification as done',
         deleteSession            => 'Delete session',
+        demoExportedVars         => 'Exported variables',
+        demoParams               => 'Demonstration parameters',
         done                     => 'done',
-        captcha_data             => 'Directory for data',
         captcha_login_enabled    => 'Activation in login form',
         captcha_mail_enabled     => 'Activation in password reset by mail form',
-        captcha_output           => 'Directory for images',
+        captcha_register_enabled => 'Activation in register form',
         captcha_size             => 'Size',
+        captchaStorage           => 'Captcha module name',
+        captchaStorageOptions    => 'Captcha module options',
         CAS_authnLevel           => 'Authentication level',
         CAS_CAFile               => 'CA file',
         CAS_gateway              => 'Gateway authentication',
@@ -147,16 +156,19 @@ sub en {
         facebookAppId                   => 'Facebook application ID',
         facebookAppSecret               => 'Facebook application secret',
         facebookAuthnLevel              => 'Authentication level',
+        facebookExportedVars            => 'Exported variables',
         facebookParams                  => 'Facebook parameters',
         failedLoginNumber               => 'Number of registered failed logins',
         generalParameters               => 'General Parameters',
         globalStorage                   => 'Apache::Session module',
         globalStorageOptions            => 'Apache::Session module parameters',
         googleAuthnLevel                => 'Authentication level',
+        googleExportedVars              => 'Exported variables',
         googleParams                    => 'Google parameters',
         grantSessionRules               => 'Opening conditions',
         groups                          => 'Groups',
         headers                         => 'HTTP Headers',
+        hGroups                         => 'Groups (HashRef)',
         hideOldPassword                 => 'Hide old password',
         httpOnly                        => 'Javascript protection',
         https                           => 'HTTPS',
@@ -184,6 +196,7 @@ sub en {
         ldapBase                        => 'Users search base',
         ldapChangePasswordAsUser        => 'Change as user',
         ldapConnection                  => 'Connection',
+        ldapExportedVars                => 'Exported variables',
         ldapFilters                     => 'Filters',
         LDAPFilter                      => 'Default filter',
         ldapGroupAttributeName          => 'Target attribute',
@@ -207,6 +220,8 @@ sub en {
         ldapTimeout                     => 'Timeout',
         ldapUsePasswordResetAttribute   => 'Use reset attribute',
         ldapVersion                     => 'Version',
+        localSessionStorage             => 'Cache module',
+        localSessionStorageOptions      => 'Cache module options',
         loginHistory                    => 'Login history',
         loginHistoryEnabled             => 'Activation',
         logoutServices                  => 'Logout forward',
@@ -254,6 +269,7 @@ sub en {
         nullParams                  => 'Null parameters',
         openIdAttr                  => 'OpenID login',
         openIdAuthnLevel            => 'Authentication level',
+        openIdExportedVars          => 'Exported variables',
         openIdIDPList               => 'Authorizated domains',
         openIdIssuerSecret          => 'Secret token',
         openIdParams                => 'OpenID parameters',
@@ -278,6 +294,7 @@ sub en {
         portal                      => 'URL',
         portalAntiFrame             => 'Anti frame protection',
         portalAutocomplete          => 'Auto complete',
+        portalButtons               => 'Buttons on login page',
         portalCaptcha               => 'Captcha',
         portalCheckLogins           => 'Check last logins',
         portalCustomization         => 'Customization',
@@ -285,12 +302,15 @@ sub en {
         portalDisplayChangePassword => 'Password change',
         portalDisplayLoginHistory   => 'Login History',
         portalDisplayLogout         => 'Logout',
+        portalDisplayRegister       => 'Register new account',
         portalDisplayResetPassword  => 'Reset password',
         portalForceAuthn            => 'Force authentication',
         portalMenu                  => 'Menu',
         portalModules               => 'Modules activation',
         portalOpenLinkInNewWindow   => 'New window',
+        portalOther                 => 'Other',
         portalParams                => 'Portal',
+        portalPingInterval          => 'Ping Interval',
         portalRedirection           => 'Portal redirections',
         portalRequireOldPassword    => 'Require old password',
         portalSkin                  => 'Default Skin',
@@ -305,6 +325,12 @@ sub en {
         radiusServer                => 'Server hostname',
         randomPasswordRegexp        => 'Regexp for password generation',
         redirection                 => 'Handler redirections',
+        register                    => 'Register new account',
+        registerConfirmSubject      => 'Subject for confirmation mail',
+        registerDB                  => 'Module',
+        registerDoneSubject         => 'Subject for done mail',
+        registerTimeout             => 'Validity time of a register request',
+        registerUrl                 => 'Page URL',
         reloadUrls                  => 'Configuration reload',
         remoteCookieName            => 'Cookie name',
         remoteGlobalStorage         => 'Sessions module',
@@ -333,6 +359,7 @@ sub en {
         singleSession               => 'One session only by user',
         singleUserByIP              => 'One user by IP address',
         slaveAuthnLevel             => 'Authentication level',
+        slaveExportedVars           => 'Exported variables',
         slaveMasterIP               => 'Master\'s IP address',
         slaveParams                 => 'Slave parameters',
         slaveUserHeader             => "Header for user login",
@@ -384,6 +411,7 @@ sub en {
         virtualHosts                => 'Virtual Hosts',
         warning                     => 'Warning',
         webIDAuthnLevel             => 'Authentication level',
+        webIDExportedVars           => 'Exported variables',
         webIDParams                 => 'WebID parameters',
         webIDWhitelist              => 'WebID whitelist',
         whatToTrace                 => "REMOTE_USER",
@@ -451,13 +479,19 @@ sub en {
         samlSPMetaDataOptionsAuthnResponse  => 'Authentication response',
         samlSPMetaDataOptionsSignature      => 'Signature',
         samlSPMetaDataOptionsSecurity       => 'Security',
-        samlServiceMetaData                 => 'SAML 2 Service',
-        samlEntityID                        => 'Entity Identifier',
-        samlOrganization                    => 'Organization',
-        samlOrganizationDisplayName         => 'Display Name',
-        samlOrganizationName                => 'Name',
-        samlOrganizationURL                 => 'URL',
-        samlSPSSODescriptor                 => 'Service Provider',
+        samlSPMetaDataOptionsEnableIDPInitiatedURL =>
+          'Enable use of IDP initiated URL',
+        samlSPMetaDataOptionsNameIDSessionKey => 'Force NameID session key',
+        samlSPMetaDataOptionsSessionNotOnOrAfterTimeout =>
+          'sessionNotOnOrAfter duration',
+        samlSPMetaDataOptionsNotOnOrAfterTimeout => 'notOnOrAfter duration',
+        samlServiceMetaData                      => 'SAML 2 Service',
+        samlEntityID                             => 'Entity Identifier',
+        samlOrganization                         => 'Organization',
+        samlOrganizationDisplayName              => 'Display Name',
+        samlOrganizationName                     => 'Name',
+        samlOrganizationURL                      => 'URL',
+        samlSPSSODescriptor                      => 'Service Provider',
         samlSPSSODescriptorAuthnRequestsSigned =>
           'Signed Authentication Request',
         samlSPSSODescriptorWantAssertionsSigned => 'Want Assertions Signed',
@@ -516,43 +550,49 @@ sub en {
         samlCommonDomainCookieReader     => 'Reader URL',
         samlCommonDomainCookieWriter     => 'Writer URL',
         samlRelayStateTimeout            => 'RelayState session timeout',
+        samlUseQueryStringSpecific       => 'Use specific query_string method',
     };
 }
 
 sub fr {
     use utf8;
     return {
-        _auth                    => 'Authentification',
-        _authChoice              => 'Choix d\'authentification',
-        _userDB                  => 'Utilisateur',
-        _passwordDB              => 'Mot de passe',
-        _issuerDB                => 'Fournisseur',
-        _timezone                => 'Zone horaire',
-        _session_id              => 'Identifiant de session',
-        _url                     => "URL d'origine",
-        _user                    => 'Identifiant',
-        _password                => 'Mot de passe',
-        _utime                   => 'Tampon de la session',
-        _lastAuthnUTime          => 'Tampon d\'authentification ',
-        _idp                     => 'Identifiant d\'entité de l\'IDP',
-        _idpConfKey              => 'Clé de configuration de l\'IDP',
-        _samlToken               => ' Jeton SAML ',
-        _lassoSessionDump        => ' Dump session Lasso ',
-        _lassoIdentityDump       => 'Dump identité Lasso',
-        advancedParams           => 'Paramètres avancés',
-        apacheParams             => 'Paramètres Apache',
-        apacheAuthnLevel         => 'Niveau d\'authentification',
-        applicationList          => 'Catégories et applications',
-        attributesAndMacros      => 'Attributs et macros',
-        authChoiceModules        => 'Modules autorisés',
-        authChoiceParam          => 'Parmètre de l\'URL',
-        authentication           => "Module d'authentification",
-        authenticationLevel      => 'Niveau d\'authentification',
-        authenticationTitle      => 'Authentification',
-        AuthLDAPFilter           => 'Filtre d\'authentification',
-        authParams               => "Modules d'authentification",
-        browserIdAuthnLevel      => "Niveau d'authentification",
-        browserIdAutoLogin       => "Authentification automatique",
+        _auth               => 'Authentification',
+        _authChoice         => 'Choix d\'authentification',
+        _authMulti          => 'Authentification (multi)',
+        _userDB             => 'Utilisateur',
+        _userDBMulti        => 'Utilisateur (multi)',
+        _passwordDB         => 'Mot de passe',
+        _issuerDB           => 'Fournisseur',
+        _timezone           => 'Zone horaire',
+        _session_id         => 'Identifiant de session',
+        _url                => "URL d'origine",
+        _user               => 'Identifiant',
+        _password           => 'Mot de passe',
+        _utime              => 'Tampon de la session',
+        _lastAuthnUTime     => 'Tampon d\'authentification ',
+        _idp                => 'Identifiant d\'entité de l\'IDP',
+        _idpConfKey         => 'Clé de configuration de l\'IDP',
+        _samlToken          => ' Jeton SAML ',
+        _lassoSessionDump   => ' Dump session Lasso ',
+        _lassoIdentityDump  => 'Dump identité Lasso',
+        adParams            => 'Paramètres Active Directory',
+        ADPwdExpireWarning  => 'Avertissement avant expiration du mot de passe',
+        ADPwdMaxAge         => 'Âge maximal du mot de passe',
+        advancedParams      => 'Paramètres avancés',
+        apacheParams        => 'Paramètres Apache',
+        apacheAuthnLevel    => 'Niveau d\'authentification',
+        applicationList     => 'Catégories et applications',
+        attributesAndMacros => 'Attributs et macros',
+        authChoiceModules   => 'Modules autorisés',
+        authChoiceParam     => 'Parmètre de l\'URL',
+        authentication      => "Module d'authentification",
+        authenticationLevel => 'Niveau d\'authentification',
+        authenticationTitle => 'Authentification',
+        AuthLDAPFilter      => 'Filtre d\'authentification',
+        authParams          => "Modules d'authentification",
+        browserIdAuthnLevel => "Niveau d'authentification",
+        browserIdAutoLogin  => "Authentification automatique",
         browserIdBackgroundColor => "Couleur d'arrière plan",
         browserIdParams          => "Paramètres BrowserID",
         browserIdSiteLogo        => "Logo du site",
@@ -569,6 +609,7 @@ sub fr {
         dbiConnection            => 'Connexion',
         dbiConnectionAuth        => 'Authentification',
         dbiConnectionUser        => 'Utilisateurs',
+        dbiExportedVars          => 'Variables exportées',
         dbiParams                => 'Paramètres DBI',
         dbiPassword              => 'Mot de passe',
         dbiPasswordMailCol       => 'Champ mail',
@@ -579,14 +620,18 @@ sub fr {
         dbiUserUser              => 'Utilisateur',
         deleteNotification       => 'Marquer la notification comme validée',
         deleteSession            => 'Effacer la session',
+        demoExportedVars         => 'Variables exportées',
+        demoParams               => 'Paramètres démonstration',
         done                     => 'validée',
-        captcha_data             => 'Répertoire des données',
         captcha_login_enabled =>
           "Activation dans le formulaire d'authentification",
         captcha_mail_enabled =>
           'Activation dans le formulaire de réinitialisation par mail',
-        captcha_output         => 'Répertoire des images',
+        captcha_register_enabled =>
+          'Activation dans le formulaire de création de compte',
         captcha_size           => 'Taille',
+        captchaStorage         => 'Nom du module de stockage',
+        captchaStorageOptions  => 'Options du module de stockage',
         CAS_authnLevel         => 'Niveau d\'authentification',
         CAS_CAFile             => 'Fichier d\'AC',
         CAS_gateway            => 'Authentification transparente',
@@ -622,6 +667,7 @@ sub fr {
         exportedVars   => 'Attributs à exporter',
         facebookAppId  => 'ID de l\'application Facebook',
         facebookAppSecret      => 'Secret de l\'application Facebook',
+        facebookExportedVars   => 'Variables exportées',
         facebookAuthnLevel     => 'Niveau d\'authentification',
         facebookParams         => 'Paramètres Facebook',
         failedLoginNumber      => 'Nombre d\'échecs de connexion mémorisés',
@@ -629,10 +675,12 @@ sub fr {
         globalStorage          => 'Module Apache::Session',
         globalStorageOptions   => 'Paramètres du module Apache::Session',
         googleAuthnLevel       => 'Niveau d\'authentification',
+        googleExportedVars     => 'Variables exportées',
         googleParams           => 'Paramètres Google',
         grantSessionRules      => "Conditions d'ouverture",
         groups                 => 'Groupes',
         headers                => 'En-têtes HTTP',
+        hGroups                => 'Groupes (HashRef)',
         hideOldPassword        => "Masquer l'ancien mot de passe",
         httpOnly               => 'Protection contre javascript',
         https                  => 'HTTPS',
@@ -660,6 +708,7 @@ sub fr {
         ldapBase                        => 'Base de recherche des utilisateurs',
         ldapChangePasswordAsUser        => 'Changement en tant qu\'utilisateur',
         ldapConnection                  => 'Connexion',
+        ldapExportedVars                => 'Variables exportées',
         ldapFilters                     => 'Filtres',
         LDAPFilter                      => 'Filtre par défaut',
         ldapGroupAttributeName          => 'Attribut cible',
@@ -683,20 +732,22 @@ sub fr {
         ldapTimeout     => 'Temps maximum d\'inactivité',
         ldapUsePasswordResetAttribute =>
           'Utiliser l\'attribut de réinitialisation',
-        ldapVersion         => 'Version',
-        loginHistory        => 'Historique des connexions',
-        loginHistoryEnabled => 'Activation',
-        logoutServices      => 'Transfert de la déconnexion',
-        logParams           => 'Journalisation',
-        macros              => 'Macros',
-        mailBody            => 'Contenu du message de succès',
-        mailCharset         => 'Charset',
-        mailConfirmBody     => 'Contenu du message de confirmation',
-        mailConfirmSubject  => 'Sujet du message de confirmation',
-        mailContent         => 'Contenu du mail',
-        mailFrom            => 'Expéditeur du message',
-        mailHeaders         => 'En-têtes du mail',
-        mailLDAPFilter      => 'Filtre mail',
+        ldapVersion                => 'Version',
+        localSessionStorage        => 'Module de cache',
+        localSessionStorageOptions => 'Paramètres du module de cache',
+        loginHistory               => 'Historique des connexions',
+        loginHistoryEnabled        => 'Activation',
+        logoutServices             => 'Transfert de la déconnexion',
+        logParams                  => 'Journalisation',
+        macros                     => 'Macros',
+        mailBody                   => 'Contenu du message de succès',
+        mailCharset                => 'Charset',
+        mailConfirmBody            => 'Contenu du message de confirmation',
+        mailConfirmSubject         => 'Sujet du message de confirmation',
+        mailContent                => 'Contenu du mail',
+        mailFrom                   => 'Expéditeur du message',
+        mailHeaders                => 'En-têtes du mail',
+        mailLDAPFilter             => 'Filtre mail',
         mailOnPasswordChange =>
           "Envoi d'un mail quand le mot de passe est changé",
         mailOther      => 'Autres',
@@ -735,6 +786,7 @@ sub fr {
         nullParams                  => 'Paramètres Null',
         openIdAttr                  => 'Identifiant OpenID',
         openIdAuthnLevel            => 'Niveau d\'authentification',
+        openIdExportedVars          => 'Variables exportées',
         openIdIDPList               => 'Domaines autorisés',
         openIdIssuerSecret          => 'Jeton secret',
         openIdParams                => 'Paramètres OpenID',
@@ -759,6 +811,7 @@ sub fr {
         portal                      => 'URL',
         portalAntiFrame             => 'Protection anti frame',
         portalAutocomplete          => 'Auto complétion',
+        portalButtons               => 'Boutons sur la page de connexion',
         portalCaptcha               => 'Captcha',
         portalCheckLogins           => 'Vérifier l\'historique',
         portalCustomization         => 'Personnalisation',
@@ -766,12 +819,15 @@ sub fr {
         portalDisplayChangePassword => 'Changement de mot de passe',
         portalDisplayLoginHistory   => 'Historique des connexions',
         portalDisplayLogout         => 'Déconnexion',
+        portalDisplayRegister       => 'Création d\'un nouveau compte',
         portalDisplayResetPassword  => 'Réinitialisation de mot de passe',
         portalForceAuthn            => 'Authentication forcée',
         portalMenu                  => 'Menu',
         portalModules               => 'Modules',
         portalOpenLinkInNewWindow   => 'Nouvelle fenêtre',
+        portalOther                 => 'Autres',
         portalParams                => 'Portail',
+        portalPingInterval          => 'Interval du ping',
         portalRedirection           => 'Redirections du portail',
         portalRequireOldPassword    => 'Ancien mot de passe requis',
         portalSkin                  => 'Thème visuel par défaut',
@@ -787,6 +843,12 @@ sub fr {
         randomPasswordRegexp =>
           'Expression regulière pour la génération des mots de passe',
         redirection                 => 'Redirections du Handler',
+        register                    => 'Créer un nouveau compte',
+        registerConfirmSubject      => 'Sujet du mail de confirmation',
+        registerDB                  => 'Module',
+        registerDoneSubject         => 'Sujet du mail de prise en compte',
+        registerTimeout             => 'Durée de validité de la requête',
+        registerUrl                 => 'URL de la page',
         reloadUrls                  => 'Mise à jour de la configuration',
         remoteCookieName            => 'Nom du cookie',
         remoteGlobalStorage         => 'Module des sessions',
@@ -815,6 +877,7 @@ sub fr {
         singleSession      => 'Une seule session par utilisateur',
         singleUserByIP     => 'Un seul utilisateur par IP',
         slaveAuthnLevel    => 'Niveau d\'authentification',
+        slaveExportedVars  => 'Variables exportées',
         slaveMasterIP      => 'IP accréditées',
         slaveParams        => 'Paramètres Slave',
         slaveUserHeader    => "En-tête identifiant l'utilisateur",
@@ -866,6 +929,7 @@ sub fr {
         virtualHosts           => 'Hôtes virtuels',
         warning                => 'Attention',
         webIDAuthnLevel        => 'Niveau d\'authentification',
+        webIDExportedVars      => 'Variables exportées',
         webIDParams            => 'Paramètres WebID',
         webIDWhitelist         => 'Liste blanche WebID',
         whatToTrace            => "REMOTE_USER",
@@ -935,13 +999,20 @@ sub fr {
         samlSPMetaDataOptionsAuthnResponse  => 'Réponse d\'authentification',
         samlSPMetaDataOptionsSignature      => 'Signature',
         samlSPMetaDataOptionsSecurity       => 'Sécurité',
-        samlServiceMetaData                 => 'Service SAML 2',
-        samlEntityID                        => 'Identifiant d\'entité',
-        samlOrganization                    => 'Organisation',
-        samlOrganizationDisplayName         => 'Nom affiché',
-        samlOrganizationName                => 'Nom',
-        samlOrganizationURL                 => 'URL',
-        samlSPSSODescriptor                 => 'Fournisseur de service',
+        samlSPMetaDataOptionsEnableIDPInitiatedURL =>
+          "Autoriser l'utilisation d'URL SSO initié par l'IDP",
+        samlSPMetaDataOptionsNameIDSessionKey =>
+          "Forcer la clé de session NameID",
+        samlSPMetaDataOptionsSessionNotOnOrAfterTimeout =>
+          'Durée sessionNotOnOrAfter',
+        samlSPMetaDataOptionsNotOnOrAfterTimeout => 'Durée notOnOrAfter',
+        samlServiceMetaData                      => 'Service SAML 2',
+        samlEntityID                             => 'Identifiant d\'entité',
+        samlOrganization                         => 'Organisation',
+        samlOrganizationDisplayName              => 'Nom affiché',
+        samlOrganizationName                     => 'Nom',
+        samlOrganizationURL                      => 'URL',
+        samlSPSSODescriptor                      => 'Fournisseur de service',
         samlSPSSODescriptorAuthnRequestsSigned =>
           'Requêtes d\'authentification signées',
         samlSPSSODescriptorWantAssertionsSigned =>
@@ -1007,6 +1078,8 @@ sub fr {
         samlCommonDomainCookieReader     => 'URL de lecture',
         samlCommonDomainCookieWriter     => 'URL d\'écriture',
         samlRelayStateTimeout => 'Durée de vie d\'une session RelayState',
+        samlUseQueryStringSpecific =>
+          "Utilisation d'une fonction spécifique pour query_string",
     };
 }
 
