@@ -10,7 +10,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_CAS;
 use base qw(Lemonldap::NG::Portal::_CAS Lemonldap::NG::Portal::_LibAccess);
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.4.3';
 
 ## @method void issuerDBInit()
 # Nothing to do
@@ -137,13 +137,13 @@ sub issuerForUnAuthUser {
         $self->lmLog( "Service ticket session $ticket found", 'debug' );
 
         # Check service
-        unless ( $service eq $casServiceSession->{service} ) {
+        unless ( $service eq $casServiceSession->data->{service} ) {
             $self->lmLog(
                 "Submitted service $service does not match initial service "
-                  . $casServiceSession->{service},
+                  . $casServiceSession->data->{service},
                 'error'
             );
-            untie %$casServiceSession;
+            $self->deleteCasSession($casServiceSession);
             $self->returnCasValidateError();
         }
 
@@ -156,40 +156,39 @@ sub issuerForUnAuthUser {
             # We should check the ST was delivered with primary credentials
             $self->lmLog( "Renew flag detected ", 'debug' );
 
-            unless ( $casServiceSession->{renew} ) {
+            unless ( $casServiceSession->data->{renew} ) {
                 $self->lmLog(
 "Authentication renew requested, but not done in former authentication process",
                     'error'
                 );
-                untie %$casServiceSession;
+                $self->deleteCasSession($casServiceSession);
                 $self->returnCasValidateError();
             }
         }
 
         # Open local session
         my $localSession =
-          $self->getApacheSession( $casServiceSession->{_cas_id}, 1 );
+          $self->getApacheSession( $casServiceSession->data->{_cas_id}, 1 );
 
         unless ($localSession) {
             $self->lmLog(
-                "Local session " . $casServiceSession->{_cas_id} . " notfound",
+                "Local session "
+                  . $casServiceSession->data->{_cas_id}
+                  . " notfound",
                 'error'
             );
-            untie %$casServiceSession;
+            $self->deleteCasSession($casServiceSession);
             $self->returnCasValidateError();
         }
 
         # Get username
         my $username =
-          $localSession->{ $self->{casAttr} || $self->{whatToTrace} };
+          $localSession->data->{ $self->{casAttr} || $self->{whatToTrace} };
 
         $self->lmLog( "Get username $username", 'debug' );
 
-        # Close sessions
-        untie %$casServiceSession;
-        untie %$localSession;
-
         # Return success message
+        $self->deleteCasSession($casServiceSession);
         $self->returnCasValidateSuccess($username);
 
         # We should not be there
@@ -261,16 +260,14 @@ sub issuerForUnAuthUser {
         $self->lmLog( "$urlType ticket session $ticket found", 'debug' );
 
         # Check service
-        unless ( $service eq $casServiceSession->{service} ) {
+        unless ( $service eq $casServiceSession->data->{service} ) {
             $self->lmLog(
                 "Submitted service $service does not match initial service "
-                  . $casServiceSession->{service},
+                  . $casServiceSession->data->{service},
                 'error'
             );
 
-            # CAS protocol: invalidate ticket if service is invalid
             $self->deleteCasSession($casServiceSession);
-
             $self->returnCasServiceValidateError( 'INVALID_SERVICE',
                 'Submitted service does not match initial service' );
         }
@@ -284,19 +281,19 @@ sub issuerForUnAuthUser {
             # We should check the ST was delivered with primary credentials
             $self->lmLog( "Renew flag detected ", 'debug' );
 
-            unless ( $casServiceSession->{renew} ) {
+            unless ( $casServiceSession->data->{renew} ) {
                 $self->lmLog(
 "Authentication renew requested, but not done in former authentication process",
                     'error'
                 );
-                untie %$casServiceSession;
+                $self->deleteCasSession($casServiceSession);
                 $self->returnCasValidateError();
             }
 
         }
 
         # Proxies (for PROXY VALIDATE only)
-        my $proxies = $casServiceSession->{proxies};
+        my $proxies = $casServiceSession->data->{proxies};
 
         # Proxy granting ticket
         if ($pgtUrl) {
@@ -310,27 +307,26 @@ sub issuerForUnAuthUser {
 
             if ($casProxyGrantingSession) {
 
+                my $PGinfos;
+
                 # PGT session
-                $casProxyGrantingSession->{type}    = 'casProxyGranting';
-                $casProxyGrantingSession->{service} = $service;
-                $casProxyGrantingSession->{_cas_id} =
-                  $casServiceSession->{_cas_id};
-                $casProxyGrantingSession->{_utime} =
-                  $casServiceSession->{_utime};
+                $PGinfos->{type}    = 'casProxyGranting';
+                $PGinfos->{service} = $service;
+                $PGinfos->{_cas_id} = $casServiceSession->data->{_cas_id};
+                $PGinfos->{_utime}  = $casServiceSession->data->{_utime};
 
                 # Trace proxies
-                $casProxyGrantingSession->{proxies} = (
+                $PGinfos->{proxies} = (
                       $proxies
                     ? $proxies . $self->{multiValuesSeparator} . $pgtUrl
                     : $pgtUrl
                 );
 
-                my $casProxyGrantingSessionID =
-                  $casProxyGrantingSession->{_session_id};
+                my $casProxyGrantingSessionID = $casProxyGrantingSession->id;
                 my $casProxyGrantingTicket =
                   "PGT-" . $casProxyGrantingSessionID;
 
-                untie %$casProxyGrantingSession;
+                $casProxyGrantingSession->update($PGinfos);
 
                 $self->lmLog(
 "CAS proxy granting session $casProxyGrantingSessionID created",
@@ -342,8 +338,7 @@ sub issuerForUnAuthUser {
 
                 if ($tmpCasSession) {
 
-                    $casProxyGrantingTicketIOU =
-                      "PGTIOU-" . $tmpCasSession->{_session_id};
+                    $casProxyGrantingTicketIOU = "PGTIOU-" . $tmpCasSession->id;
                     $self->deleteCasSession($tmpCasSession);
                     $self->lmLog(
 "Generate proxy granting ticket IOU $casProxyGrantingTicketIOU",
@@ -381,29 +376,28 @@ sub issuerForUnAuthUser {
 
         # Open local session
         my $localSession =
-          $self->getApacheSession( $casServiceSession->{_cas_id}, 1 );
+          $self->getApacheSession( $casServiceSession->data->{_cas_id}, 1 );
 
         unless ($localSession) {
             $self->lmLog(
-                "Local session " . $casServiceSession->{_cas_id} . " notfound",
+                "Local session "
+                  . $casServiceSession->data->{_cas_id}
+                  . " notfound",
                 'error'
             );
-            untie %$casServiceSession;
+            $self->deleteCasSession($casServiceSession);
             $self->returnCasServiceValidateError( 'INTERNAL_ERROR',
                 'No session associated to ticket' );
         }
 
         # Get username
         my $username =
-          $localSession->{ $self->{casAttr} || $self->{whatToTrace} };
+          $localSession->data->{ $self->{casAttr} || $self->{whatToTrace} };
 
         $self->lmLog( "Get username $username", 'debug' );
 
-        # Close sessions
-        untie %$casServiceSession;
-        untie %$localSession;
-
         # Return success message
+        $self->deleteCasSession($casServiceSession);
         $self->returnCasServiceValidateSuccess( $username,
             $casProxyGrantingTicketIOU, $proxies );
 
@@ -463,19 +457,18 @@ sub issuerForUnAuthUser {
                 'Error in proxy session management' );
         }
 
-        $casProxySession->{type}    = 'casProxy';
-        $casProxySession->{service} = $targetService;
-        $casProxySession->{_cas_id} = $casProxyGrantingSession->{_cas_id};
-        $casProxySession->{_utime}  = $casProxyGrantingSession->{_utime};
-        $casProxySession->{proxies} = $casProxyGrantingSession->{proxies};
+        my $Pinfos;
+        $Pinfos->{type}    = 'casProxy';
+        $Pinfos->{service} = $targetService;
+        $Pinfos->{_cas_id} = $casProxyGrantingSession->data->{_cas_id};
+        $Pinfos->{_utime}  = $casProxyGrantingSession->data->{_utime};
+        $Pinfos->{proxies} = $casProxyGrantingSession->data->{proxies};
 
-        my $casProxySessionID = $casProxySession->{_session_id};
+        $casProxySession->update($Pinfos);
+
+        my $casProxySessionID = $casProxySession->id;
         my $casProxyTicket    = "PT-" . $casProxySessionID;
 
-        # Close sessions
-        untie %$casProxySession;
-        untie %$casProxyGrantingSession;
-
         $self->lmLog( "CAS proxy session $casProxySessionID created", 'debug' );
 
         # Return success message
@@ -613,17 +606,18 @@ sub issuerForAuthUser {
                 return PE_ERROR;
             }
 
-            $casServiceSession->{type}    = 'casService';
-            $casServiceSession->{service} = $service;
-            $casServiceSession->{renew}   = $casRenewFlag;
-            $casServiceSession->{_cas_id} = $session_id;
-            $casServiceSession->{_utime}  = $time;
+            my $Sinfos;
+            $Sinfos->{type}    = 'casService';
+            $Sinfos->{service} = $service;
+            $Sinfos->{renew}   = $casRenewFlag;
+            $Sinfos->{_cas_id} = $session_id;
+            $Sinfos->{_utime}  = $time;
 
-            my $casServiceSessionID = $casServiceSession->{_session_id};
+            $casServiceSession->update($Sinfos);
+
+            my $casServiceSessionID = $casServiceSession->id;
             $casServiceTicket = "ST-" . $casServiceSessionID;
 
-            untie %$casServiceSession;
-
             $self->lmLog( "CAS service session $casServiceSessionID created",
                 'debug' );
         }
@@ -774,7 +768,7 @@ L<http://www.jasig.org/cas/protocol>
 
 =item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
-=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+=item François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
 =item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
@@ -796,7 +790,7 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =item Copyright (C) 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
-=item Copyright (C) 2012 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+=item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
 =item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
