@@ -9,7 +9,7 @@ use strict;
 use Lemonldap::NG::Portal::_Choice;
 use Lemonldap::NG::Portal::Simple;
 
-our $VERSION = '1.1.0';
+our $VERSION = '1.4.0';
 
 ## @apmethod int passwordDBInit()
 # Does nothing
@@ -27,4 +27,12 @@ sub modifyPassword {
     return $self->_choice->try( 'modifyPassword', 2 );
 }
 
+## @apmethod int passwordDBFinish()
+# Does nothing
+# @return Lemonldap::NG::Portal constant
+sub passwordDBFinish {
+    my $self = shift;
+    return $self->_choice->try( 'passwordDBFinish', 2 );
+}
+
 1;
