@@ -8,7 +8,7 @@ package Lemonldap::NG::Portal::UserDBDemo;
 use strict;
 use Lemonldap::NG::Portal::Simple;
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.4.0';
 
 ## @apmethod int userDBInit()
 # Check AuthDemo use
@@ -16,7 +16,11 @@ our $VERSION = '1.2.0';
 sub userDBInit {
     my $self = shift;
 
-    if ( $self->get_module('auth') eq 'Demo' ) {
+    if ( $self->get_module('auth') =~ /^Demo/ ) {
+
+        # Call authInit if demo accounts not found
+        $self->authInit() unless defined $self->{_demoAccounts};
+
         return PE_OK;
     }
     else {
@@ -33,10 +37,23 @@ sub userDBInit {
 sub getUser {
     my $self = shift;
 
-    return PE_USERNOTFOUND
-      unless ( defined $self->{_demoAccounts}->{ $self->{user} } );
+    # Search by login
+    if ( $self->{user} ) {
+        return PE_OK
+          if ( defined $self->{_demoAccounts}->{ $self->{user} } );
+    }
 
-    PE_OK;
+    # Search by mail
+    if ( $self->{mail} ) {
+        foreach my $user ( keys %{ $self->{_demoAccounts} } ) {
+            if ( $self->{_demoAccounts}->{$user}->{mail} eq $self->{mail} ) {
+                $self->{user} = $user;
+                return PE_OK;
+            }
+        }
+    }
+
+    PE_USERNOTFOUND;
 }
 
 ## @apmethod int setSessionInfo()
@@ -45,9 +62,10 @@ sub getUser {
 sub setSessionInfo {
     my $self = shift;
 
-    foreach ( keys %{ $self->{exportedVars} } ) {
-        $self->{sessionInfo}->{$_} =
-          $self->{_demoAccounts}->{ $self->{user} }->{$_}
+    my %vars = ( %{ $self->{exportedVars} }, %{ $self->{demoExportedVars} } );
+    while ( my ( $k, $v ) = each %vars ) {
+        $self->{sessionInfo}->{$k} =
+          $self->{_demoAccounts}->{ $self->{user} }->{$v}
           || "";
     }
 
