@@ -11,10 +11,11 @@ use Exporter;
 use base qw(Exporter Net::LDAP);
 use Lemonldap::NG::Portal::Simple;
 use Encode;
+use Unicode::String qw(utf8);
 use strict;
 
 our @EXPORT   = qw(ldap);
-our $VERSION  = '1.2.3';
+our $VERSION  = '1.4.6';
 our $ppLoaded = 0;
 
 BEGIN {
@@ -145,6 +146,7 @@ sub loadPP {
 # @return Lemonldap::NG portal error code
 sub userBind {
     my $self = shift;
+
     if ( $self->{portal}->{ldapPpolicyControl} ) {
 
         # Create Control object
@@ -166,24 +168,7 @@ sub userBind {
             return ( $mesg->code == 0 ? PE_OK : PE_LDAPERROR );
         }
 
-        # Get expiration warning and graces
-        if ( $resp->grace_authentications_remaining ) {
-            $self->{portal}->info( "<h3>"
-                  . $resp->grace_authentications_remaining . " "
-                  . $self->{portal}->msg(PM_PP_GRACE)
-                  . "</h3>" );
-        }
-        if ( $resp->time_before_expiration ) {
-            $self->{portal}->info(
-                "<h3>"
-                  . sprintf(
-                    $self->{portal}->msg(PM_PP_EXP_WARNING),
-                    $self->{portal}->convertSec( $resp->time_before_expiration )
-                  )
-                  . "</h3>"
-            );
-        }
-
+        # Check for ppolicy error
         my $pp_error = $resp->pp_error;
         if ( defined $pp_error ) {
             $self->{portal}->_sub( 'userError',
@@ -201,6 +186,26 @@ sub userBind {
             ]->[$pp_error];
         }
         elsif ( $mesg->code == 0 ) {
+
+            # Get expiration warning and graces
+            if ( $resp->grace_authentications_remaining ) {
+                $self->{portal}->info( "<h3>"
+                      . $resp->grace_authentications_remaining . " "
+                      . $self->{portal}->msg(PM_PP_GRACE)
+                      . "</h3>" );
+            }
+            if ( $resp->time_before_expiration ) {
+                $self->{portal}->info(
+                    "<h3>"
+                      . sprintf(
+                        $self->{portal}->msg(PM_PP_EXP_WARNING),
+                        $self->{portal}
+                          ->convertSec( $resp->time_before_expiration )
+                      )
+                      . "</h3>"
+                );
+            }
+
             return PE_OK;
         }
     }
@@ -215,31 +220,62 @@ sub userBind {
     return PE_BADCREDENTIALS;
 }
 
-## @method private int _changePassword(string newpassword,string confirmpassword,string oldpassword)
+## @method int userModifyPassword(string dn, string newpassword, string confirmpassword, string oldpassword, boolean ad)
 # Change user's password.
+# @param $dn DN
 # @param $newpassword New password
 # @param $confirmpassword New password
 # @param $oldpassword Current password
+# @param $ad Active Directory mode
 # @return Lemonldap::NG::Portal constant
 sub userModifyPassword {
-    my ( $self, $dn, $newpassword, $confirmpassword, $oldpassword ) = splice @_;
+    my ( $self, $dn, $newpassword, $confirmpassword, $oldpassword, $ad ) =
+      splice @_;
+    my $ppolicyControl     = $self->{portal}->{ldapPpolicyControl};
+    my $setPassword        = $self->{portal}->{ldapSetPassword};
+    my $asUser             = $self->{portal}->{ldapChangePasswordAsUser};
+    my $requireOldPassword = $self->{portal}->{portalRequireOldPassword};
+    my $passwordAttribute  = "userPassword";
     my $err;
     my $mesg;
 
     # Verify confirmation password matching
-    return PE_PASSWORD_MISMATCH unless ( $newpassword eq $confirmpassword );
+    unless ( $newpassword eq $confirmpassword ) {
+        $self->{portal}->lmLog(
+"Password $newpassword and password $confirmpassword are not the same",
+            'debug'
+        );
+        return PE_PASSWORD_MISMATCH;
+    }
+
+    # Adjust configuration for AD
+    if ($ad) {
+        $ppolicyControl    = 0;
+        $setPassword       = 0;
+        $passwordAttribute = "unicodePwd";
+
+        # Encode password for AD
+        $newpassword = utf8( chr(34) . $newpassword . chr(34) )->utf16le();
+        if ( $oldpassword and $asUser ) {
+            $oldpassword = utf8( chr(34) . $oldpassword . chr(34) )->utf16le();
+        }
+        $self->{portal}->lmLog( "Active Directory mode enabled", 'debug' );
+
+    }
 
     # First case: no ppolicy
-    if ( !$self->{portal}->{ldapPpolicyControl} ) {
+    if ( !$ppolicyControl ) {
 
-        if ( $self->{portal}->{ldapSetPassword} ) {
+        if ($setPassword) {
 
             # Bind as user if oldpassword and ldapChangePasswordAsUser
-            if ( $oldpassword and $self->{portal}->{ldapChangePasswordAsUser} )
-            {
+            if ( $oldpassword and $asUser ) {
 
                 $mesg = $self->bind( $dn, password => $oldpassword );
-                return PE_BADOLDPASSWORD if ( $mesg->code != 0 );
+                if ( $mesg->code != 0 ) {
+                    $self->{portal}->lmLog( "Bad old password", 'debug' );
+                    return PE_BADOLDPASSWORD;
+                }
             }
 
             # Use SetPassword extended operation
@@ -257,32 +293,86 @@ sub userModifyPassword {
               );
 
             # Catch the "Unwilling to perform" error
-            return PE_BADOLDPASSWORD if ( $mesg->code == 53 );
+            if ( $mesg->code == 53 ) {
+                $self->{portal}->lmLog( "Bad old password", 'debug' );
+                return PE_BADOLDPASSWORD;
+            }
         }
         else {
-            if ( $self->{portal}->{portalRequireOldPassword} ) {
 
-                return PE_MUST_SUPPLY_OLD_PASSWORD if ( !$oldpassword );
-
-                # Check old password with a bind
-                $mesg = $self->bind( $dn, password => $oldpassword );
-                return PE_BADOLDPASSWORD if ( $mesg->code != 0 );
-
-          # Rebind as Manager only if user is not granted to change its password
-                $self->bind()
-                  unless $self->{portal}->{ldapChangePasswordAsUser};
+            # AD specific
+            # Change password as user with a delete/add modification
+            if ( $ad and $oldpassword and $asUser ) {
+                $mesg = $self->modify(
+                    $dn,
+                    changes => [
+                        delete => [ $passwordAttribute => $oldpassword ],
+                        add    => [ $passwordAttribute => $newpassword ]
+                    ]
+                );
             }
 
-            # Use standard modification
-            $mesg =
-              $self->modify( $dn, replace => { userPassword => $newpassword } );
-        }
+            else {
+                if ($requireOldPassword) {
 
+                    return PE_MUST_SUPPLY_OLD_PASSWORD if ( !$oldpassword );
+
+                    # Check old password with a bind
+                    $mesg = $self->bind( $dn, password => $oldpassword );
+
+                    # For AD password expiration to work:
+                    # ppolicy must be desactivated,
+                    # and "change as user" must be desactivated
+                    if ($ad) {
+                        if ( $mesg->error =~ /LdapErr: .* data ([^,]+),.*/ ) {
+
+# extended data message code:
+# 532: password expired (but provided password is correct)
+# 773: must change password at next connection (but provided password is correct)
+# 52e: password is incorrect
+                            unless ( ( $1 eq '532' ) || ( $1 eq '773' ) ) {
+                                $self->{portal}
+                                  ->lmLog( "Bad old password", 'warn' );
+                                return PE_BADOLDPASSWORD;
+                            }
+                        }
+
+                   # if error message has not been catched, then it IS a success
+                    }
+                    else
+                    {   # this is not AD, a 0 error code means good old password
+                        if ( $mesg->code != 0 ) {
+                            $self->{portal}
+                              ->lmLog( "Bad old password", 'warn' );
+                            return PE_BADOLDPASSWORD;
+                        }
+                    }
+
+          # Rebind as Manager only if user is not granted to change its password
+                    $self->bind() unless $asUser;
+                }
+
+                # Use standard modification
+                $mesg =
+                  $self->modify( $dn,
+                    replace => { $passwordAttribute => $newpassword } );
+            }
+        }
+        $self->{portal}
+          ->lmLog( "Modification return code: " . $mesg->code, 'debug' );
         return PE_WRONGMANAGERACCOUNT
           if ( $mesg->code == 50 || $mesg->code == 8 );
+        return PE_PP_INSUFFICIENT_PASSWORD_QUALITY
+          if ( $mesg->code == 53 && $ad );
+        return PE_PP_PASSWORD_MOD_NOT_ALLOWED
+          if ( $mesg->code == 19 && $ad );
         return PE_LDAPERROR unless ( $mesg->code == 0 );
         $self->{portal}
           ->_sub( 'userNotice', "Password changed $self->{portal}->{user}" );
+
+        # Rebind as manager for next LDAP operations if we were bound as user
+        $self->bind() if $asUser;
+
         return PE_PASSWORD_OK;
     }
     else {
@@ -290,14 +380,15 @@ sub userModifyPassword {
         # Create Control object
         my $pp = Net::LDAP::Control::PasswordPolicy->new;
 
-        if ( $self->{portal}->{ldapSetPassword} ) {
+        if ($setPassword) {
 
             # Bind as user if oldpassword and ldapChangePasswordAsUser
-            if ( $oldpassword and $self->{portal}->{ldapChangePasswordAsUser} )
-            {
-
+            if ( $oldpassword and $asUser ) {
                 $mesg = $self->bind( $dn, password => $oldpassword );
-                return PE_BADOLDPASSWORD if ( $mesg->code != 0 );
+                if ( $mesg->code != 0 ) {
+                    $self->{portal}->lmLog( "Bad old password", 'debug' );
+                    return PE_BADOLDPASSWORD;
+                }
             }
 
 # Use SetPassword extended operation
@@ -319,24 +410,30 @@ sub userModifyPassword {
               );
 
             # Catch the "Unwilling to perform" error
-            return PE_BADOLDPASSWORD if ( $mesg->code == 53 );
+            if ( $mesg->code == 53 ) {
+                $self->{portal}->lmLog( "Bad old password", 'debug' );
+                return PE_BADOLDPASSWORD;
+            }
         }
         else {
             if ($oldpassword) {
 
                 # Check old password with a bind
                 $mesg = $self->bind( $dn, password => $oldpassword );
-                return PE_BADOLDPASSWORD if ( $mesg->code != 0 );
+                if ( $mesg->code != 0 ) {
+                    $self->{portal}->lmLog( "Bad old password", 'debug' );
+                    return PE_BADOLDPASSWORD;
+                }
 
           # Rebind as Manager only if user is not granted to change its password
                 $self->bind()
-                  unless $self->{portal}->{ldapChangePasswordAsUser};
+                  unless $asUser;
             }
 
             # Use standard modification
             $mesg = $self->modify(
                 $dn,
-                replace => { userPassword => $newpassword },
+                replace => { $passwordAttribute => $newpassword },
                 control => [$pp]
             );
         }
@@ -344,11 +441,17 @@ sub userModifyPassword {
         # Get server control response
         my ($resp) = $mesg->control("1.3.6.1.4.1.42.2.27.8.5.1");
 
+        $self->{portal}
+          ->lmLog( "Modification return code: " . $mesg->code, 'debug' );
         return PE_WRONGMANAGERACCOUNT
           if ( $mesg->code == 50 || $mesg->code == 8 );
         if ( $mesg->code == 0 ) {
             $self->{portal}->_sub( 'userNotice',
                 "Password changed $self->{portal}->{user}" );
+
+           # Rebind as manager for next LDAP operations if we were bound as user
+            $self->bind() if $asUser;
+
             return PE_PASSWORD_OK;
         }
 
@@ -381,23 +484,24 @@ sub userModifyPassword {
 # @return Lemonldap::NG::Portal::_LDAP object
 sub ldap {
     my $self = shift;
-    unless ( $self->{_multi} ) {
-        return $self->{ldap} if ( ref( $self->{ldap} ) );
-    }
-    else {
-        $self->lmLog( "LDAP Cache disabled in multi mode", 'debug' );
-    }
+    return $self->{ldap}
+      if ( ref( $self->{ldap} ) and $self->{flags}->{ldapActive} );
     if ( $self->{ldap} = Lemonldap::NG::Portal::_LDAP->new($self)
         and my $mesg = $self->{ldap}->bind )
     {
         if ( $mesg->code != 0 ) {
             $self->lmLog( "LDAP error: " . $mesg->error, 'error' );
+            $self->{ldap}->unbind;
         }
         else {
-            if ( $self->{ldapPpolicyControl} and not $self->{ldap}->loadPP() ) {
+            if ( $self->{ldapPpolicyControl}
+                and not $self->{ldap}->loadPP() )
+            {
                 $self->lmLog( "LDAP password policy error", 'error' );
+                $self->{ldap}->unbind;
             }
             else {
+                $self->{flags}->{ldapActive} = 1;
                 return $self->{ldap};
             }
         }
@@ -414,16 +518,12 @@ sub ldap {
 # @param key Attribute name in group containing searched value
 # @param value Searched value
 # @param attributes to get from found groups (array ref)
-# @return string groups separated with multiValuesSeparator
+# @return hashRef groups
 sub searchGroups {
-    my $self       = shift;
-    my $base       = shift;
-    my $key        = shift;
-    my $value      = shift;
-    my $attributes = shift;
+    my ( $self, $base, $key, $value, $attributes ) = splice @_;
 
     my $portal = $self->{portal};
-    my $groups;
+    my $groups = {};
 
     # Creating search filter
     my $searchFilter =
@@ -468,30 +568,31 @@ sub searchGroups {
                       $self->searchGroups( $base, $key, $group_value,
                         $attributes );
 
-                    $groups .=
-                      $recursive_groups . $portal->{multiValuesSeparator}
-                      if ($recursive_groups);
+                    my %allGroups = ( %$groups, %$recursive_groups )
+                      if ( ref $recursive_groups );
+                    $groups = \%allGroups;
                 }
             }
 
+            # Use first attribute as group name
+            my $groupName = $entry->get_value( $attributes->[0] );
+            $groups->{$groupName}->{name} = $groupName;
+
             # Now parse attributes
             foreach (@$attributes) {
 
                 # Next if group attribute value
                 next if ( $_ eq $portal->{ldapGroupAttributeValueGroup} );
 
-                my $data = $entry->get_value($_);
+                my $data = $entry->get_value( $_, asref => 1 );
 
                 if ($data) {
-                    $portal->lmLog( "Store $data in groups", 'debug' );
-                    $groups .= $data . "|";
+                    $portal->lmLog( "Store values of $_ in group $groupName",
+                        'debug' );
+                    $groups->{$groupName}->{$_} = $data;
                 }
             }
-            $groups =~ s/\|$//g;
-            $groups .= $portal->{multiValuesSeparator};
         }
-
-        $groups =~ s/\Q$portal->{multiValuesSeparator}\E$//;
     }
 
     return $groups;
@@ -503,9 +604,7 @@ sub searchGroups {
 # @param attribute Attribute name
 # @return string value
 sub getLdapValue {
-    my $self      = shift;
-    my $entry     = shift;
-    my $attribute = shift;
+    my ( $self, $entry, $attribute ) = splice @_;
 
     return $entry->dn() if ( $attribute eq "dn" );
 
