@@ -8,7 +8,7 @@ package Lemonldap::NG::Portal::_WebForm;
 use Lemonldap::NG::Portal::Simple qw(:all);
 use strict;
 
-our $VERSION = '1.3.2';
+our $VERSION = '1.4.0';
 
 ## @apmethod int authInit()
 # Does nothing.
@@ -134,24 +134,4 @@ sub setAuthSessionInfo {
     PE_OK;
 }
 
-## @method int checkCaptcha(code, ccode)
-# Check captcha auth
-# @param code that user enter in the form
-# @param captcha code generated by Authen::Captcha
-# @return a constant
-sub checkCaptcha {
-    my ( $self, $code, $ccode ) = splice @_;
-
-    opendir( OUTPUT, $self->{captcha_output} )
-      or $self->lmLog( "Can't open captcha output dir", "error" );
-    opendir( DATA, $self->{captcha_data} )
-      or $self->lmLog( "Can't open captcha data dir", "error" );
-
-    my $result = $self->{captcha}->check_code( $code, $ccode );
-
-    closedir(OUTPUT) && closedir(DATA);
-
-    return $result;
-}
-
 1;
